@@ -1,5 +1,6 @@
 # Uses `from x import y as y` for compatibility with `pyright --verifytypes` (#2625)
 
+from .. import _deprecate as _deprecate
 from .._core import (
     MockClock as MockClock,
     wait_all_tasks_blocked as wait_all_tasks_blocked,
@@ -28,12 +29,30 @@ from ._memory_streams import (
     memory_stream_pump as memory_stream_pump,
 )
 from ._network import open_stream_to_socket_listener as open_stream_to_socket_listener
-from ._raises_group import Matcher as Matcher, RaisesGroup as RaisesGroup
+from ._raises_group import Matcher as _Matcher, RaisesGroup as _RaisesGroup
 from ._sequencer import Sequencer as Sequencer
 from ._trio_test import trio_test as trio_test
 
 ################################################################
 
 
+_deprecate.deprecate_attributes(
+    __name__,
+    {
+        "RaisesGroup": _deprecate.DeprecatedAttribute(
+            _RaisesGroup,
+            version="0.33.0",
+            issue=3326,
+            instead="See https://docs.pytest.org/en/stable/reference/reference.html#pytest.RaisesGroup",
+        ),
+        "Matcher": _deprecate.DeprecatedAttribute(
+            _Matcher,
+            version="0.33.0",
+            issue=3326,
+            instead="See https://docs.pytest.org/en/stable/reference/reference.html#pytest.RaisesExc",
+        ),
+    },
+)
+
 fixup_module_metadata(__name__, globals())
 del fixup_module_metadata
